@@ -1,4 +1,7 @@
-__version__ = "0.0.3"
+__version__ = "0.0.4"
+import os
+
+
 def kolibri_userinfo(claims, user):
     """
     Fill claims with the information available in the Kolibri database
@@ -6,5 +9,7 @@ def kolibri_userinfo(claims, user):
     claims["name"] = user.full_name
     COUNTRY = os.environ.get("COUNTRY", None)
     if COUNTRY:
-        claims["email"] = "{username}@{country}.org".format(username=user.username, country=COUNTRY)
+        claims["email"] = "{username}@{country}.org".format(
+            username=user.username, country=COUNTRY
+        )
     return claims
